__author__ = 'Robert Ancell <bob27@users.sourceforge.net>'
__license__ = 'GNU General Public License Version 2'
__copyright__ = 'Copyright 2005-2006  Robert Ancell'

import game
import cecp

class AIProfile:
    """
    """

    name       = None
    executable = None
    arguments  = None
    
    def __init__(self, name, executable, arguments = []):
        """
        """
        self.name = name
        self.executable = executable
        self.arguments = arguments

class AIPlayer(game.ChessPlayer, cecp.CECPConnection):
    """
    """
    
    # The profile we are using
    __profile = None
    
    __moving = False
    
    def __init__(self, name, profile):
        """Constructor for an AI player.
        
        'name' is the name of the player (string).
        'profile' is the profile to use for the AI (AIProfile).
        """
        self.__profile = profile

        game.ChessPlayer.__init__(self, name)
        cecp.CECPConnection.__init__(self, profile.executable, profile.arguments)
        
    # Public methods

    def getProfile(self):
        """
        """
        return self.__profile
        
    def tick(self):
        """
        """
        self.read()
        
    # Private methods
        
    def onAIMove(self, move):
        """Called by cecp.CECPConnection"""
        self.__moving = True
        self.move(move)

    def onPlayerMoved(self, player, move):
        """Called by game.ChessPlayer"""
        if self.__moving:
            self.__moving = False
        else:
            self.reportMove(move.canMove)
    
    def readyToMove(self):
        """Called by game.ChessPlayer"""
        self.requestMove()
        
    def onGameEnded(self, winningPlayer = None):
        """Called by game.ChessPlayer"""
        self.quit()
